@@ -3,13 +3,13 @@
 /***************************************************************
 *  Inline-Relational-Record Editing
 *
-* $Id: jsfunc.inline.js 9135 2010-10-18 02:21:18Z stan $
+* $Id$
 *
 *
 *
 *  Copyright notice
 *
-*  (c) 2006-2009 Oliver Hader <oh@inpublica.de>
+*  (c) 2006-2011 Oliver Hader <oh@inpublica.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -36,6 +36,7 @@ var inline = {
 	lockedAjaxMethod: {},
 	sourcesLoaded: {},
 	data: {},
+	isLoading: false,
 
 	addToDataArray: function(object) {
 		$H(object).each(function(pair) {
@@ -45,10 +46,23 @@ var inline = {
 	setPrependFormFieldNames: function(value) {	this.prependFormFieldNames = value; },
 	setNoTitleString: function(value) { this.noTitleString = value; },
 
-	expandCollapseRecord: function(objectId, expandSingle) {
+	expandCollapseRecord: function(objectId, expandSingle, returnURL) {
 		var currentUid = this.parseObjectId('none', objectId, 1);
 		var objectPrefix = this.parseObjectId('full', objectId, 0, 1);
 
+			// if content is not loaded yet, get it now from server
+		if(($(objectId+'_fields') && $("irre-loading-indicator"+objectId)) || inline.isLoading) {
+			return false;
+		} else if ($(objectId+'_fields') && $(objectId+'_fields').innerHTML.substr(0,16) == '<!--notloaded-->') {
+			inline.isLoading = true;
+				// add loading-indicator
+			if ($(objectId + '_icon')) {
+				$(objectId + '_icon').hide();
+				$(objectId + '_iconcontainer').addClassName('loading-indicator');
+			}
+			return this.getRecordDetails(objectId, returnURL);
+		}
+
 		var currentState = '';
 		var collapse = new Array();
 		var expand = new Array();
@@ -105,6 +119,11 @@ var inline = {
 		}
 	},
 
+	getRecordDetails: function(objectId, returnURL) {
+		inline.makeAjaxCall('getRecordDetails', [inline.getNumberOfRTE(), objectId, returnURL], true);
+		return false;
+	},
+
 	createNewRecord: function(objectId, recordUid) {
 		if (this.isBelowMax(objectId)) {
 			if (recordUid) {
@@ -137,8 +156,8 @@ var inline = {
 			options = {
 				method:		'post',
 				parameters:	urlParams,
-				onSuccess:	function(xhr) { inline.processAjaxResponse(method, xhr); },
-				onFailure:	function(xhr) { inline.showAjaxFailure(method, xhr); }
+				onSuccess:	function(xhr) { inline.isLoading = false; inline.processAjaxResponse(method, xhr); },
+				onFailure:	function(xhr) { inline.isLoading = false; inline.showAjaxFailure(method, xhr); }
 			};
 
 			new Ajax.Request(url, options);
@@ -352,6 +371,19 @@ var inline = {
 				new Insertion.After(insertObject, htmlData);
 		}
 	},
+	domAddRecordDetails: function(objectId, objectPrefix, expandSingle, htmlData) {
+		var objectDiv = $(objectId + '_fields');
+		if (!objectDiv || objectDiv.innerHTML.substr(0,16) != '<!--notloaded-->')
+			return;
+		objectDiv.update(htmlData);
+			// remove loading-indicator
+		if ($(objectId + '_icon')) {
+			$(objectId + '_iconcontainer').removeClassName('loading-indicator');
+			$(objectId + '_icon').show();
+		}
+			// now that the content is loaded, set the expandState
+		this.expandCollapseRecord(objectId, expandSingle);
+	},
 
 		// Get script and link elements from head tag:
 	getDomHeadChildren: function(head) {
@@ -685,6 +717,12 @@ var inline = {
 			TBE_EDITOR.removeElementArray(removeStack);
 		}
 
+			// Mark this container as deleted
+		var deletedRecordContainer = $(objectId + '_div');
+		if (deletedRecordContainer) {
+			deletedRecordContainer.addClassName('inlineIsDeletedRecord');
+		}
+
 			// If the record is new and was never saved before, just remove it from DOM:
 		if (this.isNewRecord(objectId) || options && options.forceDirectRemoval) {
 			this.fadeAndRemove(objectId+'_div');
@@ -901,7 +939,7 @@ var inline = {
 
 	setVisibilityOfElementsWithClassName: function(action, selector, parentElement) {
 		var domObjects = Selector.findChildElements($(parentElement), [selector]);
-		if (action == 'hide') { 
+		if (action == 'hide') {
 			$A(domObjects).each(function(domObject) { new Effect.Fade(domObject); });
 		} else if (action == 'show') {
 			$A(domObjects).each(function(domObject) { new Effect.Appear(domObject); });
@@ -968,4 +1006,4 @@ Object.extend(Array.prototype, {
 	}
 });
 
-/*]]>*/
\ No newline at end of file
+/*]]>*/
