@@ -1,7 +1,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2007-2009 Ingo Renner <ingo@typo3.org>
+*  (c) 2007-2011 Ingo Renner <ingo@typo3.org>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -28,7 +28,7 @@
 /**
  * class to handle the shortcut menu
  *
- * $Id: shortcutmenu.js 6539 2009-11-25 14:49:14Z stucki $
+ * $Id$
  */
 var ShortcutMenu = Class.create({
 
@@ -36,15 +36,15 @@ var ShortcutMenu = Class.create({
 	 * registers for resize event listener and executes on DOM ready
 	 */
 	initialize: function() {
-		Event.observe(window, 'resize', this.positionMenu);
-
-		Event.observe(window, 'load', function(){
-			this.positionMenu();
-			this.toolbarItemIcon = $$('#shortcut-menu .toolbar-item img')[0].src;
+		Ext.onReady(function() {
+			Event.observe(window, 'resize', TYPO3BackendToolbarManager.positionMenu('shortcut-menu'));
+			TYPO3BackendToolbarManager.positionMenu('shortcut-menu');
+			
+			this.toolbarItemIcon = $$('#shortcut-menu .toolbar-item span.t3-icon')[0];
 
 			Event.observe($$('#shortcut-menu .toolbar-item')[0], 'click', this.toggleMenu);
 			this.initControls();
-		}.bindAsEventListener(this));
+		}, this);
 	},
 
 	/**
@@ -57,7 +57,7 @@ var ShortcutMenu = Class.create({
 			var shortcutId = element.up('tr.shortcut').identify().slice(9);
 
 				// map InPlaceEditor to edit icons
-			new Ajax.InPlaceEditor('shortcut-label-' + shortcutId, 'ajax.php?ajaxID=ShortcutMenu::saveShortcut', {
+			var edit = new Ajax.InPlaceEditor('shortcut-label-' + shortcutId, 'ajax.php?ajaxID=ShortcutMenu::saveShortcut', {
 				externalControl     : 'shortcut-edit-' + shortcutId,
 				externalControlOnly : true,
 				highlightcolor      : '#f9f9f9',
@@ -78,7 +78,6 @@ var ShortcutMenu = Class.create({
 
 				// follow/execute shortcuts
 			element.observe('click', function(event) {
-				Event.stop(event);
 				this.toggleMenu();
 			}.bind(this));
 
@@ -87,11 +86,11 @@ var ShortcutMenu = Class.create({
 			// activate delete icon
 		$$('.shortcut-delete img').each(function(element) {
 			element.observe('click', function(event) {
-				if(confirm('Do you really want to remove this shortcut?')) {
+				if (confirm('Do you really want to remove this bookmark?')) {
 					var deleteControl = event.element();
 					var shortcutId = deleteControl.up('tr.shortcut').identify().slice(9);
 
-					new Ajax.Request('ajax.php', {
+					var del = new Ajax.Request('ajax.php', {
 						parameters : 'ajaxID=ShortcutMenu::delete&shortcutId=' + shortcutId,
 						onComplete : this.reRenderMenu.bind(this)
 					});
@@ -101,32 +100,6 @@ var ShortcutMenu = Class.create({
 
 	},
 
-	/**
-	 * positions the menu below the toolbar icon, let's do some math!
-	 */
-	positionMenu: function() {
-		var calculatedOffset = 0;
-		var parentWidth      = $('shortcut-menu').getWidth();
-		var ownWidth         = $$('#shortcut-menu .toolbar-item-menu')[0].getWidth();
-		var parentSiblings   = $('shortcut-menu').previousSiblings();
-
-		parentSiblings.each(function(toolbarItem) {
-			calculatedOffset += toolbarItem.getWidth() - 1;
-			// -1 to compensate for the margin-right -1px of the list items,
-			// which itself is necessary for overlaying the separator with the active state background
-
-			if(toolbarItem.down().hasClassName('no-separator')) {
-				calculatedOffset -= 1;
-			}
-		});
-		calculatedOffset = calculatedOffset - ownWidth + parentWidth;
-
-
-		$$('#shortcut-menu .toolbar-item-menu')[0].setStyle({
-			left: calculatedOffset + 'px'
-		});
-	},
-
 	/**
 	 * toggles the visibility of the menu and places it under the toolbar icon
 	 */
@@ -135,7 +108,7 @@ var ShortcutMenu = Class.create({
 		var menu        = $$('#shortcut-menu .toolbar-item-menu')[0];
 		toolbarItem.blur();
 
-		if(!toolbarItem.hasClassName('toolbar-item-active')) {
+		if (!toolbarItem.hasClassName('toolbar-item-active')) {
 			toolbarItem.addClassName('toolbar-item-active');
 			Effect.Appear(menu, {duration: 0.2});
 			TYPO3BackendToolbarManager.hideOthers(toolbarItem);
@@ -143,8 +116,6 @@ var ShortcutMenu = Class.create({
 			toolbarItem.removeClassName('toolbar-item-active');
 			Effect.Fade(menu, {duration: 0.1});
 		}
-
-		Event.stop(event);
 	},
 
 	/**
@@ -161,13 +132,13 @@ var ShortcutMenu = Class.create({
 		var firstInGroup    = null;
 		var shortcutGroupId = 0;
 
-		if(shortcut.hasClassName('first-row')) {
+		if (shortcut.hasClassName('first-row')) {
 			firstInGroup = shortcut;
 		} else {
 			firstInGroup = shortcut.previous('.first-row');
 		}
 
-		if(undefined != firstInGroup) {
+		if (undefined !== firstInGroup) {
 			shortcutGroupId = firstInGroup.previous().identify().slice(15);
 		}
 
@@ -181,12 +152,12 @@ var ShortcutMenu = Class.create({
 			// first create an option for "no group"
 		option = document.createElement('option');
 		option.value = 0;
-		option.selected = (shortcutGroupId == 0 ? true : false);
+		option.selected = (shortcutGroupId === 0 ? true : false);
 		option.appendChild(document.createTextNode('No Group'));
 		selectField.appendChild(option);
 
 			// get the groups
-		new Ajax.Request('ajax.php', {
+		var getGroups = new Ajax.Request('ajax.php', {
 			method: 'get',
 			parameters: 'ajaxID=ShortcutMenu::getGroups',
 			asynchronous: false, // needs to be synchronous to build the options before adding the selectfield
@@ -199,7 +170,7 @@ var ShortcutMenu = Class.create({
 				shortcutGroups.each(function(group) {
 					option = document.createElement('option');
 					option.value = group.key
-					option.selected = (shortcutGroupId == group.key ? true : false);
+					option.selected = (shortcutGroupId === group.key ? true : false);
 					option.appendChild(document.createTextNode(group.value));
 					selectField.appendChild(option);
 				});
@@ -218,7 +189,7 @@ var ShortcutMenu = Class.create({
 	 */
 	reRenderMenu: function(transport, element, backPath) {
 		var container = $$('#shortcut-menu .toolbar-item-menu')[0];
-		if(!backPath) {
+		if (!backPath) {
 			var backPath = '';
 		}
 
@@ -228,7 +199,7 @@ var ShortcutMenu = Class.create({
 		});
 		container.update('LOADING');
 
-		new Ajax.Updater(
+		var render = new Ajax.Updater(
 			container,
 			backPath + 'ajax.php',
 			{
@@ -249,17 +220,21 @@ var ShortcutMenu = Class.create({
 	 * when finished it reloads the menu
 	 */
 	createShortcut: function(backPath, moduleName, url) {
-		$$('#shortcut-menu .toolbar-item img')[0].src = 'gfx/spinner.gif';
+		var toolbarItemIcon = $$('#shortcut-menu .toolbar-item span.t3-icon')[0];
+
+		var parent = Element.up(toolbarItemIcon);
+		var spinner = new Element('span').addClassName('spinner');
+		var oldIcon = toolbarItemIcon.replace(spinner);
 
 			// synchrous call to wait for it to complete and call the render
 			// method with backpath _afterwards_
-		new Ajax.Request(backPath + 'ajax.php', {
+		var call = new Ajax.Request(backPath + 'ajax.php', {
 			parameters : 'ajaxID=ShortcutMenu::create&module=' + moduleName + '&url=' + url,
 			asynchronous : false
 		});
 
 		this.reRenderMenu(null, null, backPath);
-		$$('#shortcut-menu .toolbar-item img')[0].src = this.toolbarItemIcon;
+		spinner.replace(oldIcon);
 	}
 
 });
