@@ -1,7 +1,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2010 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -26,7 +26,7 @@
 /**
  * Contains JavaScript for TYPO3 Core Form generator - AKA "TCEforms"
  *
- * $Id: jsfunc.tbe_editor.js 6277 2009-10-26 23:18:47Z ohader $
+ * $Id$
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  * @coauthor	Oliver Hader <oh@inpublica.de>
@@ -73,7 +73,7 @@ var TBE_EDITOR = {
 		cm: new Image(),
 		sel: new Image(),
 		clear: new Image()
-	},	
+	},
 
 	// Handling of data structures:
 	addElements: function(elements) {
@@ -196,6 +196,15 @@ var TBE_EDITOR = {
 			if (type == 'required') {
 				form = document[TBE_EDITOR.formname][elementName];
 				if (form) {
+						// Check if we are within a deleted inline element
+					var testNode = $(form.parentNode);
+					while(testNode) {
+						if (testNode.hasClassName && testNode.hasClassName('inlineIsDeletedRecord')) {
+							return result;
+						}
+						testNode = $(testNode.parentNode);
+					}
+
 					var value = form.value;
 					if (!value || elementData.additional && elementData.additional.isPositiveNumber && (isNaN(value) || Number(value) <= 0)) {
 						result = 0;
@@ -206,15 +215,27 @@ var TBE_EDITOR = {
 					}
 				}
 			} else if (type == 'range' && elementData.range) {
+				var numberOfElements = 0;
 				form = document[TBE_EDITOR.formname][elementName+'_list'];
 				if (!form) {
 						// special treatment for IRRE fields:
 					var tempObj = document[TBE_EDITOR.formname][elementName];
 					if (tempObj && Element.hasClassName(tempObj, 'inlineRecord')) {
 						form = tempObj.value ? tempObj.value.split(',') : [];
+						numberOfElements = form.length;
+					}
+
+				} else {
+						// special treatment for file uploads
+					var tempObj = document[TBE_EDITOR.formname][elementName.replace(/^data/, 'data_files')];
+					numberOfElements = form.length;
+
+					if (tempObj && tempObj.type == 'file' && tempObj.value) {
+						numberOfElements++; // Add new uploaded file to the number of elements
 					}
 				}
-				if (!TBE_EDITOR.checkRange(form, elementData.range[0], elementData.range[1])) {
+
+				if (!TBE_EDITOR.checkRange(numberOfElements, elementData.range[0], elementData.range[1])) {
 					result = 0;
 					if (autoNotify) {
 						TBE_EDITOR.setImage('req_'+elementData.rangeImg, TBE_EDITOR.images.req);
@@ -320,9 +341,12 @@ var TBE_EDITOR = {
 			return true;
 		}
 	},
+	/**
+	 * This function is not used by core and will be removed in version 4.6
+	 * @deprecated
+	 */
 	setHiddenContent: function(RTEcontent,theField) {
 		document[TBE_EDITOR.formname][theField].value = RTEcontent;
-		alert(document[TBE_EDITOR.formname][theField].value);
 	},
 	fieldChanged_fName: function(fName,el) {
 		var idx=2+TBE_EDITOR.prependFormFieldNamesCnt;
@@ -397,13 +421,6 @@ var TBE_EDITOR = {
 	 */
 	checkSubmit: function(sendAlert) {
 		var funcIndex, funcMax, funcRes;
-		if (TBE_EDITOR.backend_interface == "backend_old") {
-			if (TBE_EDITOR.checkLoginTimeout() && confirm(TBE_EDITOR.labels.refresh_login)) {
-				vHWin=window.open(TBE_EDITOR.backPath+'login_frameset.php?','relogin','height=300,width=400,status=0,menubar=0');
-				vHWin.focus();
-				return false;
-			}
-		}
 		var OK=1;
 
 		// $this->additionalJS_submit:
@@ -434,8 +451,13 @@ var TBE_EDITOR = {
 			return false;
 		}
 	},
-	checkRange: function(el,lower,upper) {
-		if (el && el.length>=lower && el.length<=upper) {
+	checkRange: function(numberOfElements, lower, upper) {
+			// for backwards compatibility, check if we're dealing with an element as first parameter
+		if(typeof numberOfElements == 'object') {
+			numberOfElements = numberOfElements.length;
+		}
+
+		if (numberOfElements >= lower && numberOfElements <= upper) {
 			return true;
 		} else {
 			return false;
@@ -465,7 +487,7 @@ var TBE_EDITOR = {
 	},
 	submitForm: function() {
 		if (TBE_EDITOR.doSaveFieldName) {
-			document[TBE_EDITOR.formname][TBE_EDITOR.doSaveFieldName].value=1;			
+			document[TBE_EDITOR.formname][TBE_EDITOR.doSaveFieldName].value=1;
 		}
 		document[TBE_EDITOR.formname].submit();
 	},
@@ -516,11 +538,7 @@ var TBE_EDITOR = {
 	rawurlencode: function(str,maxlen) {
 		var output = str;
 		if (maxlen)	output = output.substr(0,200);
-		output = escape(output);
-		output = TBE_EDITOR.str_replace("*","%2A", output);
-		output = TBE_EDITOR.str_replace("+","%2B", output);
-		output = TBE_EDITOR.str_replace("/","%2F", output);
-		output = TBE_EDITOR.str_replace("@","%40", output);
+		output = Ext.urlEncode({'' : output});
 		return output;
 	},
 	str_replace: function(match,replace,string) {
@@ -540,18 +558,34 @@ var TBE_EDITOR = {
 	},
 	toggle_display_states: function(id, state_1, state_2) {
 		var node = document.getElementById(id);
-		if (node) {	
+		if (node) {
 			switch (node.style.display) {
 				case state_1:
 					node.style.display = state_2;
 					break;
 				case state_2:
-					node.style.display = state_1; 
+					node.style.display = state_1;
 					break;
 			}
 		}
 		return false;
-	}	
+	},
+
+	/**
+	 * Determines backend path to be used for e.g. ajax.php
+	 * @return string
+	 */
+	getBackendPath: function() {
+		var backendPath = '';
+		if (TYPO3) {
+			if (TYPO3.configuration && TYPO3.configuration.PATH_typo3) {
+				backendPath = TYPO3.configuration.PATH_typo3;
+			} else if (TYPO3.settings && TYPO3.settings.PATH_typo3) {
+				backendPath = TYPO3.settings.PATH_typo3;
+			}
+		}
+		return backendPath;
+	}
 };
 
 function typoSetup	() {
