@@ -32,7 +32,7 @@
  * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License, version 3 or later
  * @see \F3\TYPO3CR\FLOW3\Persistence\DataMapper, \F3\TYPO3CR\FLOW3\Persistence\Backend
  */
-class Tx_Extbase_Persistence_IdentityMap {
+class Tx_Extbase_Persistence_IdentityMap implements t3lib_Singleton {
 
 	/**
 	 * @var Tx_Extbase_Persistence_ObjectStorage
@@ -100,7 +100,7 @@ class Tx_Extbase_Persistence_IdentityMap {
 	public function getIdentifierByObject($object) {
 		if (!is_object($object)) throw new InvalidArgumentException('Object expected, ' . gettype($object) . ' given.', 1246892972);
 		if (!isset($this->objectMap[$object])) {
-			throw new Tx_Extbase_Persistence_Exception_UnknownObjectException('The given object (class: ' . get_class($object) . ') is not registered in this Identity Map.', 1246892970);
+			throw new Tx_Extbase_Persistence_Exception_UnknownObject('The given object (class: ' . get_class($object) . ') is not registered in this Identity Map.', 1246892970);
 		}
 		return $this->objectMap[$object];
 	}
