@@ -31,10 +31,15 @@
  *
  * @package Extbase
  * @subpackage Persistence
- * @version $Id: LazyLoadingProxy.php 2442 2010-07-26 09:27:29Z jocrau $
+ * @version $Id: LazyLoadingProxy.php 2262 2010-05-02 09:37:34Z jocrau $
  */
 class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Persistence_LoadingStrategyInterface {
 
+	/**
+	 * @var Tx_Extbase_Persistence_DataMapper
+	 */
+	protected $dataMapper;
+
 	/**
 	 * The object this property is contained in.
 	 *
@@ -55,7 +60,7 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 	 * @var mixed
 	 */
 	private $fieldValue;
-	
+
 	/**
 	 * Constructs this proxy instance.
 	 *
@@ -69,6 +74,16 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 		$this->fieldValue = $fieldValue;
 	}
 
+	/**
+	 * Injects the DataMapper to map nodes to objects
+	 *
+	 * @param Tx_Extbase_Persistence_Mapper_DataMapper $dataMapper
+	 * @return void
+	 */
+	public function injectDataMapper(Tx_Extbase_Persistence_Mapper_DataMapper $dataMapper) {
+		$this->dataMapper = $dataMapper;
+	}
+
 	/**
 	 * Populate this proxy by asking the $population closure.
 	 *
@@ -79,9 +94,9 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 		// usually that does not happen, but if the proxy is held from outside
 		// it's parent... the result would be weird.
 		if ($this->parentObject->_getProperty($this->propertyName) instanceof Tx_Extbase_Persistence_LazyLoadingProxy) {
-			$dataMapper = Tx_Extbase_Dispatcher::getPersistenceManager()->getBackend()->getDataMapper();
-			$objects = $dataMapper->fetchRelated($this->parentObject, $this->propertyName, $this->fieldValue, FALSE, FALSE);
-			$propertyValue = $dataMapper->mapResultToPropertyValue($this->parentObject, $this->propertyName, $objects);
+			
+			$objects = $this->dataMapper->fetchRelated($this->parentObject, $this->propertyName, $this->fieldValue, FALSE, FALSE);
+			$propertyValue = $this->dataMapper->mapResultToPropertyValue($this->parentObject, $this->propertyName, $objects);
 			$this->parentObject->_setProperty($this->propertyName, $propertyValue);
 			$this->parentObject->_memorizeCleanState($this->propertyName);
 			return $propertyValue;
@@ -99,6 +114,9 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 	 */
 	public function __call($methodName, $arguments) {
 		$realInstance = $this->_loadRealInstance();
+		if (!is_object($realInstance)) {
+			return NULL;
+		}
 		return call_user_func_array(array($realInstance, $methodName), $arguments);
 	}
 
@@ -146,7 +164,7 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 		$realInstance = $this->_loadRealInstance();
 		unset($realInstance->$propertyName);
 	}
-	
+
 	/**
 	 * Magic toString call implementation.
 	 *
@@ -156,7 +174,7 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 		$realInstance = $this->_loadRealInstance();
 		return $realInstance->__toString();
 	}
-	
+
 	/**
 	 * Returns the current value of the storage array
 	 *
@@ -186,7 +204,7 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 		$realInstance = $this->_loadRealInstance();
 		next($realInstance);
 	}
-	
+
 	/**
 	 * Resets the array pointer of the storage
 	 *
@@ -206,7 +224,7 @@ class Tx_Extbase_Persistence_LazyLoadingProxy implements Iterator, Tx_Extbase_Pe
 		return $this->current() !== FALSE;
 	}
 
-	
-	
+
+
 }
-?>
+?>
\ No newline at end of file
