@@ -45,13 +45,27 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	 **/
 	protected $tableName;
 
+	/**
+	 * The record type stored in the "type" field as configured in $TCA
+	 *
+	 * @var string
+	 **/
+	protected $recordType;
+
+	/**
+	 * The subclasses of the current class
+	 *
+	 * @var array
+	 **/
+	protected $subclasses = array();
+
 	/**
 	 * An array of column maps configured in $TCA
 	 *
 	 * @var array
 	 **/
-	protected $columnMaps;
-		
+	protected $columnMaps = array();
+
 	/**
 	 * @var string
 	 **/
@@ -91,7 +105,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	 * @var string
 	 **/
 	protected $disabledFlagColumnName;
-	
+
 	/**
 	 * @var string
 	 **/
@@ -107,14 +121,24 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	 **/
 	protected $frontendUserGroupColumnName;
 
+	/**
+	 * @var string
+	 **/
+	protected $recordTypeColumnName;
+
 	/**
 	 * Constructs this DataMap
 	 *
-	 * @param string $className The class name. This determines the table to fetch the configuration for
+	 * @param string $className The class name
+	 * @param string $tableName The table name
+	 * @param string $recordType The record type
+	 * @param array $subclasses The subclasses
 	 */
-	public function __construct($className, $tableName) {
+	public function __construct($className, $tableName, $recordType = NULL, array $subclasses = array()) {
 		$this->setClassName($className);
 		$this->setTableName($tableName);
+		$this->setRecordType($recordType);
+		$this->setSubclasses($subclasses);
 	}
 
 	/**
@@ -152,7 +176,45 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function getTableName() {
 		return $this->tableName;
 	}
-	
+
+	/**
+	 * Sets the record type
+	 *
+	 * @param string $recordType The record type
+	 * @return void
+	 */
+	public function setRecordType($recordType) {
+		$this->recordType = $recordType;
+	}
+
+	/**
+	 * Returns the record type
+	 *
+	 * @return string The record type
+	 */
+	public function getRecordType() {
+		return $this->recordType;
+	}
+
+	/**
+	 * Sets the subclasses
+	 *
+	 * @param array $subclasses An array of subclasses
+	 * @return void
+	 */
+	public function setSubclasses(array $subclasses) {
+		$this->subclasses = $subclasses;
+	}
+
+	/**
+	 * Returns the subclasses
+	 *
+	 * @return array The subclasses
+	 */
+	public function getSubclasses() {
+		return $this->subclasses;
+	}
+
 	/**
 	 * Adds a given column map to the data map.
 	 *
@@ -162,7 +224,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function addColumnMap(Tx_Extbase_Persistence_Mapper_ColumnMap $columnMap) {
 		$this->columnMaps[$columnMap->getPropertyName()] = $columnMap;
 	}
-	
+
 	/**
 	 * Returns the column map corresponding to the given property name.
 	 *
@@ -182,8 +244,8 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function isPersistableProperty($propertyName) {
 		return isset($this->columnMaps[$propertyName]);
 	}
-	
-	
+
+
 	/**
 	 * Sets the name of a column holding the page id
 	 *
@@ -193,7 +255,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function setPageIdColumnName($pageIdColumnName) {
 		$this->pageIdColumnName = $pageIdColumnName;
 	}
-	
+
 	/**
 	 * Sets the name of a column holding the page id
 	 *
@@ -202,7 +264,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function getPageIdColumnName() {
 		return $this->pageIdColumnName;
 	}
-	
+
  	/**
  	 * Sets the name of a column holding the language id of the record
  	 *
@@ -212,7 +274,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
  	public function setLanguageIdColumnName($languageIdColumnName) {
  		$this->languageIdColumnName = $languageIdColumnName;
  	}
-		
+
  	/**
  	 * Returns the name of a column holding the language id of the record.
  	 *
@@ -221,7 +283,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
  	public function getLanguageIdColumnName() {
  		return $this->languageIdColumnName;
  	}
-	
+
  	/**
  	 * Sets the name of a column holding the the uid of the record which this record is a translation of.
  	 *
@@ -231,7 +293,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
  	public function setTranslationOriginColumnName($translationOriginColumnName) {
  		$this->translationOriginColumnName = $translationOriginColumnName;
  	}
-		
+
  	/**
  	 * Returns the name of a column holding the the uid of the record which this record is a translation of.
  	 *
@@ -240,7 +302,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
  	public function getTranslationOriginColumnName() {
  		return $this->translationOriginColumnName;
  	}
-	
+
 	/**
 	 * Sets the name of a column holding the timestamp the record was modified
 	 *
@@ -250,7 +312,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function setModificationDateColumnName($modificationDateColumnName) {
 		$this->modificationDateColumnName = $modificationDateColumnName;
 	}
-	
+
 	/**
 	 * Returns the name of a column holding the timestamp the record was modified
 	 *
@@ -259,7 +321,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function getModificationDateColumnName() {
 		return $this->modificationDateColumnName;
 	}
-	
+
 	/**
 	 * Sets the name of a column holding the creation date timestamp
 	 *
@@ -269,7 +331,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function setCreationDateColumnName($creationDateColumnName) {
 		$this->creationDateColumnName = $creationDateColumnName;
 	}
-	
+
 	/**
 	 * Returns the name of a column holding the creation date timestamp
 	 *
@@ -278,7 +340,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function getCreationDateColumnName() {
 		return $this->creationDateColumnName;
 	}
-	
+
 	/**
 	 * Sets the name of a column holding the uid of the back-end user who created this record
 	 *
@@ -307,7 +369,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function setDeletedFlagColumnName($deletedFlagColumnName) {
 		$this->deletedFlagColumnName = $deletedFlagColumnName;
 	}
-	
+
 	/**
 	 * Returns the name of a column indicating the 'deleted' state of the row
 	 *
@@ -316,7 +378,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function getDeletedFlagColumnName() {
 		return $this->deletedFlagColumnName;
 	}
-	
+
 	/**
 	 * Sets the name of a column indicating the 'hidden' state of the row
 	 *
@@ -326,7 +388,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function setDisabledFlagColumnName($disabledFlagColumnName) {
 		$this->disabledFlagColumnName = $disabledFlagColumnName;
 	}
-	
+
 	/**
 	 * Returns the name of a column indicating the 'hidden' state of the row
 	 *
@@ -335,7 +397,7 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 	public function getDisabledFlagColumnName() {
 		return $this->disabledFlagColumnName;
 	}
-	
+
 	/**
 	 * Sets the name of a column holding the timestamp the record should not displayed before
 	 *
@@ -393,4 +455,23 @@ class Tx_Extbase_Persistence_Mapper_DataMap {
 		return $this->frontendUserGroupColumnName;
 	}
 
+	/**
+	 * Sets the name of a column holding the record type
+	 *
+	 * @param string $recordTypeColumnName The field name
+	 * @return void
+	 */
+	public function setRecordTypeColumnName($recordTypeColumnName) {
+		$this->recordTypeColumnName = $recordTypeColumnName;
+	}
+
+	/**
+	 * Sets the name of a column holding the record type
+	 *
+	 * @return string The field name
+	 */
+	public function getRecordTypeColumnName() {
+		return $this->recordTypeColumnName;
+	}
+
 }
\ No newline at end of file
