@@ -30,7 +30,7 @@
  *
  * @package Extbase
  * @subpackage Persistence
- * @version $Id: Query.php 2208 2010-04-14 13:41:14Z jocrau $
+ * @version $Id$
  * @scope prototype
  * @api
  */
@@ -41,18 +41,23 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 	 */
 	protected $type;
 
+	/**
+	 * @var Tx_Extbase_Object_ObjectManagerInterface
+	 */
+	protected $objectManager;
+
 	/**
 	 * @var Tx_Extbase_Persistence_DataMapper
 	 */
 	protected $dataMapper;
 
 	/**
-	 * @var Tx_Extbase_Persistence_Manager
+	 * @var Tx_Extbase_Persistence_ManagerInterface
 	 */
 	protected $persistenceManager;
 
 	/**
-	 * @var Tx_Extbase_Persistence_QOM_QueryObjectModelFactoryInterface
+	 * @var Tx_Extbase_Persistence_QOM_QueryObjectModelFactory
 	 */
 	protected $qomFactory;
 
@@ -102,6 +107,14 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 		$this->type = $type;
 	}
 
+	/**
+	 * @param Tx_Extbase_Object_ObjectManagerInterface $objectManager
+	 * @return void
+	 */
+	public function injectObjectManager(Tx_Extbase_Object_ObjectManagerInterface $objectManager) {
+		$this->objectManager = $objectManager;
+	}
+
 	/**
 	 * Injects the persistence manager, used to fetch the CR session
 	 *
@@ -110,7 +123,6 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 	 */
 	public function injectPersistenceManager(Tx_Extbase_Persistence_ManagerInterface $persistenceManager) {
 		$this->persistenceManager = $persistenceManager;
-		$this->qomFactory = $this->persistenceManager->getBackend()->getQomFactory();
 	}
 
 	/**
@@ -123,6 +135,16 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 		$this->dataMapper = $dataMapper;
 	}
 
+	/**
+	 * Injects the Query Object Model Factory
+	 *
+	 * @param Tx_Extbase_Persistence_QOM_QueryObjectModelFactory $qomFactory
+	 * @return void
+	 */
+	public function injectQomFactory(Tx_Extbase_Persistence_QOM_QueryObjectModelFactory $qomFactory) {
+		$this->qomFactory = $qomFactory;
+	}
+
 	/**
 	 * Sets the Query Settings. These Query settings must match the settings expected by
 	 * the specific Storage Backend.
@@ -137,7 +159,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 
 	/**
 	 * Returns the Query Settings.
-	 * 
+	 *
 	 * @return Tx_Extbase_Persistence_QuerySettingsInterface $querySettings The Query Settings
 	 * @api This method is not part of FLOW3 API
 	 */
@@ -164,7 +186,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 	public function setSource(Tx_Extbase_Persistence_QOM_SourceInterface $source) {
 		$this->source = $source;
 	}
-	
+
 	/**
 	 * Returns the selectorn name or an empty string, if the source is not a selector
 	 * // TODO This has to be checked at another place
@@ -193,28 +215,29 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 	/**
 	 * Executes the query against the database and returns the result
 	 *
-	 * @return array<object> The query result as an array of objects
+	 * @return Tx_Extbase_Persistence_QueryResultInterface|array The query result object or an array if $this->getQuerySettings()->getReturnRawQueryResult() is TRUE
 	 * @api
 	 */
 	public function execute() {
-		$rows = $this->persistenceManager->getObjectDataByQuery($this);
 		if ($this->getQuerySettings()->getReturnRawQueryResult() === TRUE) {
-			return $rows;
+			return $this->persistenceManager->getObjectDataByQuery($this);
 		} else {
-			return $this->dataMapper->map($this->getType(), $rows);
+			return $this->objectManager->create('Tx_Extbase_Persistence_QueryResultInterface', $this);
 		}
 	}
-	
+
 	/**
 	 * Executes the number of matching objects for the query
 	 *
 	 * @return integer The number of matching objects
+	 * @deprecated since Extbase 1.3.0; was removed in FLOW3; will be removed in Extbase 1.4.0; use Query::execute()::count() instead
 	 * @api
 	 */
 	public function count() {
+		t3lib_div::logDeprecatedFunction();
 		return $this->persistenceManager->getObjectCountByQuery($this);
 	}
-	
+
 	/**
 	 * Sets the property names to order the result by. Expected like this:
 	 * array(
@@ -231,7 +254,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 		$this->orderings = $orderings;
 		return $this;
 	}
-	
+
 	/**
 	 * Returns the property names to order the result by. Like this:
 	 * array(
@@ -293,7 +316,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 	public function getOffset() {
 		return $this->offset;
 	}
-	
+
 	/**
 	 * The constraint used to limit the result set. Returns $this to allow
 	 * for chaining (fluid interface)
@@ -319,7 +342,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 		$this->statement = $this->qomFactory->statement($statement, $parameters);
 		return $this;
 	}
-	
+
 	/**
 	 * Returns the statement of this query.
 	 *
@@ -328,7 +351,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 	public function getStatement() {
 		return $this->statement;
 	}
-	
+
 	/**
 	 * Gets the constraint for this query.
 	 *
@@ -366,7 +389,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 		}
 		return $resultingConstraint;
 	}
-	
+
 	/**
 	 * Performs a logical disjunction of the two given constraints
 	 *
@@ -465,7 +488,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 			$operand
 			);
 	}
-	
+
 	/**
 	 * Returns a "contains" criterion used for matching objects against a query.
 	 * It matches if the multivalued property contains the given operand.
@@ -496,7 +519,7 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 		if (!is_array($operand) && (!$operand instanceof ArrayAccess) && (!$operand instanceof Traversable)) {
 			throw new Tx_Extbase_Persistence_Exception_UnexpectedTypeException('The "in" operator must be given a mutlivalued operand (array, ArrayAccess, Traversable).', 1264678095);
 		}
-		
+
 		return $this->qomFactory->comparison(
 			$this->qomFactory->propertyValue($propertyName, $this->getSelectorName()),
 			Tx_Extbase_Persistence_QueryInterface::OPERATOR_IN,
@@ -567,6 +590,23 @@ class Tx_Extbase_Persistence_Query implements Tx_Extbase_Persistence_QueryInterf
 			$operand
 			);
 	}
-		
+
+	/**
+	 * @return void
+	 */
+	public function __wakeup() {
+		$this->objectManager = t3lib_div::makeInstance('Tx_Extbase_Object_ObjectManager');
+		$this->persistenceManager = $this->objectManager->get('Tx_Extbase_Persistence_ManagerInterface');
+		$this->dataMapper = $this->objectManager->get('Tx_Extbase_Persistence_Mapper_DataMapper');
+		$this->qomFactory = $this->objectManager->get('Tx_Extbase_Persistence_QOM_QueryObjectModelFactory');
+	}
+
+	/**
+	 * @return array
+	 */
+	public function __sleep() {
+		return array('type', 'source', 'constraint', 'statement', 'orderings', 'limit', 'offset', 'querySettings');
+	}
+
 }
 ?>
\ No newline at end of file
