@@ -30,10 +30,10 @@
  *
  * @package Extbase
  * @subpackage Utility
- * @version $Id: ClassLoader.php 2469 2010-07-26 09:30:14Z jocrau $
+ * @version $Id: ClassLoader.php 1729 2009-11-25 21:37:20Z stucki $
  */
 class Tx_Extbase_Utility_ClassLoader {
-	
+
 	/**
 	 * Loads php files containing classes or interfaces found in the classes directory of
 	 * an extension.
@@ -42,9 +42,9 @@ class Tx_Extbase_Utility_ClassLoader {
 	 * @uses t3lib_extMgm::extPath()
 	 * @return void
 	 */
-	public static function loadClass($className) {
+	static public function loadClass($className) {
 		$classNameParts = explode('_', $className, 3);
-		$extensionKey = Tx_Extbase_Utility_Extension::convertCamelCaseToLowerCaseUnderscored($classNameParts[1]);
+		$extensionKey = t3lib_div::camelCaseToLowerCaseUnderscored($classNameParts[1]);
 		if (t3lib_extMgm::isLoaded($extensionKey)) {
 			$classFilePathAndName = t3lib_extMgm::extPath($extensionKey) . 'Classes/' . strtr($classNameParts[2], '_', '/') . '.php';
 			if (file_exists($classFilePathAndName)) {
@@ -52,6 +52,6 @@ class Tx_Extbase_Utility_ClassLoader {
 			}
 		}
 	}
-	
+
 }
 ?>
\ No newline at end of file
