@@ -2,8 +2,8 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2007-2009 Steffen Kamper <info@sk-typo3.de>
-*  Based on Newloginbox (c) 2002-2004 Kasper Skaarhoj <kasper@typo3.com>
+*  (c) 2007-2011 Steffen Kamper <info@sk-typo3.de>
+*  Based on Newloginbox (c) 2002-2004 Kasper Skårhøj <kasper@typo3.com>
 *
 *  All rights reserved
 *
@@ -128,16 +128,25 @@ class tx_felogin_pi1 extends tslib_pibase {
 			}
 		}
 
-
-
 			// Process the redirect
 		if (($this->logintype === 'login' || $this->logintype === 'logout') && $this->redirectUrl && !$this->noRedirect) {
 			if (!$GLOBALS['TSFE']->fe_user->cookieId) {
-				$content .= '<p style="color:red; font-weight:bold;">' . $this->pi_getLL('cookie_warning', '', 1) . '</p>';
+				$content .= $this->cObj->stdWrap($this->pi_getLL('cookie_warning', '', 1), $this->conf['cookieWarning_stdWrap.']);
 			} else {
 				t3lib_utility_Http::redirect($this->redirectUrl);
 			}
 		}
+
+			// Adds hook for processing of extra item markers / special
+		if (isset($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['postProcContent']) && is_array($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['postProcContent'])) {
+			$_params = array(
+				'content' => $content
+			);
+			foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['postProcContent'] as $_funcRef) {
+				$content = t3lib_div::callUserFunction($_funcRef, $_params, $this);
+			}
+		}
+
 		return $this->conf['wrapContentInBaseClass'] ? $this->pi_wrapInBaseClass($content) : $content;
 
 	}
@@ -434,7 +443,11 @@ class tx_felogin_pi1 extends tslib_pibase {
 						}
 					}
 				}
-
+					// show logout form directly
+				if ($this->conf['showLogoutFormAfterLogin']) {
+					$this->redirectUrl = '';
+					return $this->showLogout();
+				}
 			} else {
 					// login error
 				$markerArray['###STATUS_HEADER###'] = $this->getDisplayText('error_header',$this->conf['errorHeader_stdWrap.']);
@@ -466,7 +479,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 		if (t3lib_div::inList($this->conf['redirectMode'], 'referer') || t3lib_div::inList($this->conf['redirectMode'], 'refererDomains')) {
 			$referer = $this->referer ? $this->referer : t3lib_div::getIndpEnv('HTTP_REFERER');
 			if ($referer) {
-				$extraHiddenAr[] = '<input type="hidden" name="referer" value="' . rawurlencode($referer) . '" />';
+				$extraHiddenAr[] = '<input type="hidden" name="referer" value="' . htmlspecialchars($referer) . '" />';
 			}
 		}
 
@@ -482,7 +495,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 			$onSubmit = implode('; ', $onSubmitAr).'; return true;';
 		}
 		if (count($extraHiddenAr)) {
-			$extraHidden = implode(chr(10), $extraHiddenAr);
+			$extraHidden = implode(LF, $extraHiddenAr);
 		}
 
 		if (!$gpRedirectUrl && $this->redirectUrl) {
@@ -511,7 +524,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 		}
 
 
-			// Permanent Login is only possible if permalogin is not deactivated (-1) and lifetime is greater than 0
+			// The permanent login checkbox should only be shown if permalogin is not deactivated (-1), not forced to be always active (2) and lifetime is greater than 0
 		if ($this->conf['showPermaLogin'] && t3lib_div::inList('0,1', $GLOBALS['TYPO3_CONF_VARS']['FE']['permalogin']) && $GLOBALS['TYPO3_CONF_VARS']['FE']['lifetime'] > 0) {
 			$markerArray['###PERMALOGIN###'] = $this->pi_getLL('permalogin', '', 1);
 			if($GLOBALS['TYPO3_CONF_VARS']['FE']['permalogin'] == 1) {
@@ -585,7 +598,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 								if (preg_match('/^http://([[:alnum:]._-]+)//', $url, $match)) {
 									$redirect_domain = $match[1];
 									$found = false;
-									foreach(split(',', $this->conf['domains']) as $d) {
+									foreach(t3lib_div::trimExplode(',', $this->conf['domains'], TRUE) as $d) {
 										if (preg_match('/(^|\.)/'.$d.'$', $redirect_domain)) {
 											$found = true;
 											break;
@@ -677,6 +690,10 @@ class tx_felogin_pi1 extends tslib_pibase {
 			$flex['showPermaLogin'] = $this->flexFormValue('showPermaLogin', 'sDEF');
 		}
 
+		if ($this->flexFormValue('showLogoutFormAfterLogin', 'sDEF')) {
+			$flex['showLogoutFormAfterLogin'] = $this->flexFormValue('showLogoutFormAfterLogin', 'sDEF');
+		}
+
 		if ($this->flexFormValue('pages', 'sDEF')) {
 			$flex['pages'] = $this->flexFormValue('pages', 'sDEF');
 		}
@@ -947,8 +964,8 @@ class tx_felogin_pi1 extends tslib_pibase {
 
 
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/felogin/pi1/class.tx_felogin_pi1.php'])	{
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/felogin/pi1/class.tx_felogin_pi1.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/felogin/pi1/class.tx_felogin_pi1.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/felogin/pi1/class.tx_felogin_pi1.php']);
 }
 
 ?>
\ No newline at end of file
