@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2008-2009 Stanislas Rolland <typo3(arobas)sjbr.ca>
+*  (c) 2008-2011 Stanislas Rolland <typo3(arobas)sjbr.ca>
 *  All rights reserved
 *
 *  This script is part of the Typo3 project. The Typo3 project is
@@ -26,13 +26,10 @@
  *
  * @author Stanislas Rolland <typo3(arobas)sjbr.ca>
  *
- * TYPO3 SVN ID: $Id: class.tx_rtehtmlarea_language.php 5061 2009-02-24 02:38:22Z stan $
+ * TYPO3 SVN ID: $Id$
  *
  */
-
-require_once(t3lib_extMgm::extPath('rtehtmlarea').'class.tx_rtehtmlareaapi.php');
-
-class tx_rtehtmlarea_language extends tx_rtehtmlareaapi {
+class tx_rtehtmlarea_language extends tx_rtehtmlarea_api {
 
 	protected $extensionKey = 'rtehtmlarea';	// The key of the extension that is extending htmlArea RTE
 	protected $pluginName = 'Language';		// The name of the plugin registered by the extension
@@ -74,25 +71,31 @@ class tx_rtehtmlarea_language extends tx_rtehtmlareaapi {
 	public function buildJavascriptConfiguration($RTEcounter) {
 		$button = 'language';
 		$registerRTEinJavascriptString = '';
-		if (in_array($button, $this->toolbar)) {
-			if (!is_array( $this->thisConfig['buttons.']) || !is_array($this->thisConfig['buttons.'][$button . '.'])) {
-				$registerRTEinJavascriptString .= '
-			RTEarea['.$RTEcounter.'].buttons.'. $button .' = new Object();';
-			}
-			if ($this->htmlAreaRTE->is_FE()) {
-				$first = $GLOBALS['TSFE']->getLLL('No language mark',$this->LOCAL_LANG);
-			} else {
-				$first = $GLOBALS['LANG']->getLL('No language mark');
-			}
-			$languages = array('none' => $first);
-			$languages = array_merge($languages, $this->getLanguages());
-			$languagesJSArray = 'HTMLArea.languageOptions = ' . json_encode(array_flip($languages));
+		if (!is_array( $this->thisConfig['buttons.']) || !is_array($this->thisConfig['buttons.'][$button . '.'])) {
 			$registerRTEinJavascriptString .= '
-			RTEarea['.$RTEcounter.'].buttons.'. $button .'.languagesUrl = "' . $this->htmlAreaRTE->writeTemporaryFile('', 'languages_'.$this->htmlAreaRTE->contentLanguageUid, 'js', $languagesJSArray) . '";';
+		RTEarea['.$RTEcounter.'].buttons.'. $button .' = new Object();';
 		}
+		if ($this->htmlAreaRTE->is_FE()) {
+			$first = $GLOBALS['TSFE']->getLLL('No language mark',$this->LOCAL_LANG);
+		} else {
+			$first = $GLOBALS['LANG']->getLL('No language mark');
+		}
+		$languages = array('none' => $first);
+		$languages = array_flip(array_merge($languages, $this->getLanguages()));
+		$languagesJSArray = array();
+		foreach ($languages as $key => $value) {
+			$languagesJSArray[] = array('text' => $key, 'value' => $value);
+		}
+		if ($this->htmlAreaRTE->is_FE()) {
+			$GLOBALS['TSFE']->csConvObj->convArray($languagesJSArray, $this->htmlAreaRTE->OutputCharset, 'utf-8');
+		} else {
+			$GLOBALS['LANG']->csConvObj->convArray($languagesJSArray, $GLOBALS['LANG']->charSet, 'utf-8');
+		}
+		$languagesJSArray = json_encode(array('options' => $languagesJSArray));
+		$registerRTEinJavascriptString .= '
+	RTEarea['.$RTEcounter.'].buttons.'. $button .'.dataUrl = "' . $this->htmlAreaRTE->writeTemporaryFile('', $button . '_' . $this->htmlAreaRTE->contentLanguageUid, 'js', $languagesJSArray) . '";';
 		return $registerRTEinJavascriptString;
 	}
-
 	/**
 	 * Getting all languages into an array
 	 * 	where the key is the ISO alpha-2 code of the language
@@ -102,41 +105,47 @@ class tx_rtehtmlarea_language extends tx_rtehtmlareaapi {
 	 * @return	array		An array of names of languages
 	 */
 	function getLanguages() {
-		$where = '1=1';
-		$table = 'static_languages';
-		$lang = tx_staticinfotables_div::getCurrentLanguage();
 		$nameArray = array();
-		$titleFields = tx_staticinfotables_div::getTCAlabelField($table, TRUE, $lang);
-		$prefixedTitleFields = array();
-		foreach ($titleFields as $titleField) {
-			$prefixedTitleFields[] = $table.'.'.$titleField;
-		}
-		$labelFields = implode(',', $prefixedTitleFields);
-			// Restrict to certain languages
-		if (is_array($this->thisConfig['buttons.']) && is_array($this->thisConfig['buttons.']['language.']) && isset($this->thisConfig['buttons.']['language.']['restrictToItems'])) {
-			$languageList = implode("','", t3lib_div::trimExplode(',', $GLOBALS['TYPO3_DB']->fullQuoteStr(strtoupper($this->thisConfig['buttons.']['language.']['restrictToItems']), $table)));
-			$where .= ' AND '. $table . '.lg_iso_2 IN (' . $languageList . ')';
-		}
-		$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
-			$table.'.lg_iso_2,'.$table.'.lg_country_iso_2,'.$labelFields,
-			$table,
-			$where.' AND lg_constructed = 0 '.
-			($this->htmlAreaRTE->is_FE() ? $GLOBALS['TSFE']->sys_page->enableFields($table) : t3lib_BEfunc::BEenableFields($table) .  t3lib_BEfunc::deleteClause($table))
-			);
-		$prefixLabelWithCode = !$this->thisConfig['buttons.']['language.']['prefixLabelWithCode'] ? false : true;
-		$postfixLabelWithCode = !$this->thisConfig['buttons.']['language.']['postfixLabelWithCode'] ? false : true;
-		while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)) {
-			$code = strtolower($row['lg_iso_2']).($row['lg_country_iso_2']?'-'.strtoupper($row['lg_country_iso_2']):'');
+		if (t3lib_extMgm::isLoaded('static_info_tables')) {
+			$where = '1=1';
+			$table = 'static_languages';
+			$lang = tx_staticinfotables_div::getCurrentLanguage();
+			$titleFields = tx_staticinfotables_div::getTCAlabelField($table, TRUE, $lang);
+			$prefixedTitleFields = array();
 			foreach ($titleFields as $titleField) {
-				if ($row[$titleField]) {
-					$nameArray[$code] = $this->htmlAreaRTE->is_FE() ? $GLOBALS['TSFE']->csConv($row[$titleField], $GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['static_info_tables']['charset']) : ($this->htmlAreaRTE->TCEform->inline->isAjaxCall ? $GLOBALS['LANG']->csConvObj->utf8_encode($row[$titleField], $GLOBALS['LANG']->charSet) : $row[$titleField]);
-					$nameArray[$code] = $prefixLabelWithCode ? ($code . ' - ' . $nameArray[$code]) : ($postfixLabelWithCode ? ($nameArray[$code] . ' - ' . $code) : $nameArray[$code]);
-					break;
+				$prefixedTitleFields[] = $table.'.'.$titleField;
+			}
+			$labelFields = implode(',', $prefixedTitleFields);
+				// Restrict to certain languages
+			if (is_array($this->thisConfig['buttons.']) && is_array($this->thisConfig['buttons.']['language.']) && isset($this->thisConfig['buttons.']['language.']['restrictToItems'])) {
+				$languageList = implode("','", t3lib_div::trimExplode(',', $GLOBALS['TYPO3_DB']->fullQuoteStr(strtoupper($this->thisConfig['buttons.']['language.']['restrictToItems']), $table)));
+				$where .= ' AND '. $table . '.lg_iso_2 IN (' . $languageList . ')';
+			}
+			$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
+				$table.'.lg_iso_2,'.$table.'.lg_country_iso_2,'.$labelFields,
+				$table,
+				$where.' AND lg_constructed = 0 '.
+				($this->htmlAreaRTE->is_FE() ? $GLOBALS['TSFE']->sys_page->enableFields($table) : t3lib_BEfunc::BEenableFields($table) .  t3lib_BEfunc::deleteClause($table))
+				);
+			$prefixLabelWithCode = !$this->thisConfig['buttons.']['language.']['prefixLabelWithCode'] ? false : true;
+			$postfixLabelWithCode = !$this->thisConfig['buttons.']['language.']['postfixLabelWithCode'] ? false : true;
+			while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)) {
+				$code = strtolower($row['lg_iso_2']).($row['lg_country_iso_2']?'-'.strtoupper($row['lg_country_iso_2']):'');
+				foreach ($titleFields as $titleField) {
+					if ($row[$titleField]) {
+						$nameArray[$code] = $prefixLabelWithCode ? ($code . ' - ' . $row[$titleField]) : ($postfixLabelWithCode ? ($row[$titleField] . ' - ' . $code) : $row[$titleField]);
+						break;
+					}
 				}
 			}
+			$GLOBALS['TYPO3_DB']->sql_free_result($res);
+			if ($this->htmlAreaRTE->is_FE()) {
+				$GLOBALS['TSFE']->csConvObj->convArray($nameArray, $GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['static_info_tables']['charset'], $this->htmlAreaRTE->OutputCharset);
+			} else {
+				$GLOBALS['LANG']->csConvObj->convArray($nameArray, $GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['static_info_tables']['charset'], $GLOBALS['LANG']->charSet);
+			}
+			uasort($nameArray, 'strcoll');
 		}
-		$GLOBALS['TYPO3_DB']->sql_free_result($res);
-		uasort($nameArray, 'strcoll');
 		return $nameArray;
 	}
 
@@ -155,9 +164,7 @@ class tx_rtehtmlarea_language extends tx_rtehtmlareaapi {
 		}
 	}
 }
-
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/extensions/Language/class.tx_rtehtmlarea_language.php']) {
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/extensions/Language/class.tx_rtehtmlarea_language.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/extensions/Language/class.tx_rtehtmlarea_language.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/extensions/Language/class.tx_rtehtmlarea_language.php']);
 }
-
 ?>
\ No newline at end of file
