@@ -3,7 +3,7 @@
 ########################################################################
 # Extension Manager/Repository config file for ext "sys_action".
 #
-# Auto generated 25-11-2009 22:10
+# Auto generated 26-01-2011 20:08
 #
 # Manual updates:
 # Only the data in the array - everything else is removed by next
@@ -33,13 +33,12 @@ $EM_CONF[$_EXTKEY] = array(
 	'author_company' => 'Curby Soft Multimedia',
 	'CGLcompliance' => '',
 	'CGLcompliance_note' => '',
-	'version' => '1.2.0',
-	'_md5_values_when_last_written' => 'a:15:{s:8:"TODO.txt";s:4:"17ff";s:22:"class.tx_sysaction.php";s:4:"6103";s:12:"ext_icon.gif";s:4:"f410";s:14:"ext_tables.php";s:4:"6561";s:14:"ext_tables.sql";s:4:"c36f";s:13:"locallang.xml";s:4:"6f52";s:27:"locallang_csh_sysaction.xml";s:4:"a1d4";s:17:"locallang_tca.xml";s:4:"dd78";s:14:"sys_action.gif";s:4:"eb3a";s:17:"sys_action__h.gif";s:4:"7a29";s:7:"tca.php";s:4:"f3d0";s:46:"toolbarmenu/class.tx_sysaction_toolbarmenu.php";s:4:"978d";s:35:"toolbarmenu/registerToolbarItem.php";s:4:"58a6";s:29:"toolbarmenu/tx_sysactions.css";s:4:"bd1b";s:28:"toolbarmenu/tx_sysactions.js";s:4:"deb0";}',
+	'version' => '2.0.0',
+	'_md5_values_when_last_written' => 'a:15:{s:16:"ext_autoload.php";s:4:"9b72";s:12:"ext_icon.gif";s:4:"804a";s:14:"ext_tables.php";s:4:"cd52";s:14:"ext_tables.sql";s:4:"c36f";s:13:"locallang.xml";s:4:"1f94";s:27:"locallang_csh_sysaction.xml";s:4:"a1d4";s:17:"locallang_tca.xml";s:4:"abe1";s:7:"tca.php";s:4:"1604";s:16:"x-sys_action.png";s:4:"8076";s:14:"doc/manual.sxw";s:4:"5228";s:32:"task/class.tx_sysaction_task.php";s:4:"62e6";s:46:"toolbarmenu/class.tx_sysaction_toolbarmenu.php";s:4:"96e5";s:35:"toolbarmenu/registerToolbarItem.php";s:4:"58a6";s:29:"toolbarmenu/tx_sysactions.css";s:4:"e1fa";s:28:"toolbarmenu/tx_sysactions.js";s:4:"f7da";}',
 	'constraints' => array(
 		'depends' => array(
-			'taskcenter' => '',
-			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.3.0-4.3.99',
+			'taskcenter' => '2.0.0-0.0.0',
+			'typo3' => '4.4.0-0.0.0',
 		),
 		'conflicts' => array(
 		),
